#!/bin/sh

# Usage: Must run this script on the MDS first! The snapshot
# MDT(s) must be mounted before mounting the snapshot OST(s)

FS_NAME="epsilon"

if [ `hostname | grep oss` ]; then
    SNAP="./lvsnap.sh -nc -pv -pc 23.5 -ch 256 -dv"
elif [ `hostname | grep mds` ];then
    SNAP="./lvsnap.sh -nc -pv -pc 15 -ch 256 -lt 300g -dv"
fi

# Scan for LVM devs
LV_DEVS="`lvdisplay | grep "LV Name" | grep -v -e "SS-" -e "snap" | awk '{print $3}'`"

# Umount all snapshot FS's
umount_snaps() {
    echo; echo "Unmounting filesystem snapshots:"; echo "----"
    umount -f /mnt/lustre/snapshots/*-SS-*
    if [ $? -ne 0 ]; then
        echo "Umounting snapshots failed!"
    #    exit 1
    fi
}

snap_devs() {
    echo; echo "Rotating and creating snapshots:"; echo "----"
    for lv in ${LV_DEVS}; do
        $SNAP $lv
        sleep 10
    done
}

rename_lustrefs() {
    # Scan for LV snapshots
    LV_SNAPS="`lvdisplay | grep "LV Name" | grep "SS-" | awk '{print $3}'`"

    # Rename snapshots, delete last_rcvd and remount
    echo; echo "Renaming Lustre filesystems:"; echo "----"
    for ss in ${LV_SNAPS}; do
        SS_NO="`echo $ss | cut -f3 -d-`"
        SS_MT="/mnt/lustre/snapshots/`echo $ss | cut -f4 -d /`"
        tunefs.lustre --reformat --writeconf --fsname=${FS_NAME}${SS_NO} $ss

        mkdir -p ${SS_MT}
        mount -t ldiskfs $ss ${SS_MT} && rm -f ${SS_MT}/last_rcvd
        umount ${SS_MT}

        mount -t lustre -o _netdev $ss ${SS_MT}
    done
}

# Main
#umount_snaps
snap_devs
rename_lustrefs

